==> designer-asset-1.0.10-20251121.071429-2-sources.jar: com/digiwin/athena/dto/asset/DesignerCreateAssetReqDto.java <==
package com.digiwin.athena.dto.asset;

import com.digiwin.athena.dto.action.MultiLanguageDTO;
import com.digiwin.athena.mongodb.domain.application.Asset;
import com.digiwin.athena.mongodb.domain.application.AssetDefinition;
import lombok.Data;

import java.util.Map;

@Data
public class DesignerCreateAssetReqDto {

    private String assetId;
    // 资产类型
    private String type;

    private String code;


    private String businessData;

    private String assetName;

    private String assetDesc;

    private Map<String, MultiLanguageDTO> lang;

    private Asset.ManageContext manageContext = new Asset.ManageContext();
    private Asset.ShowField showFields = new Asset.ShowField();

    public AssetDefinition convertAssetDefinition() {
        AssetDefinition assetDefinition = new AssetDefinition();
        assetDefinition.setType(this.type);
        assetDefinition.setCode(this.code);
        assetDefinition.setSource(AssetDefinition.SD_SOURCE);
        assetDefinition.setBusinessData(this.businessData);
        assetDefinition.setAssetName(this.assetName);
        assetDefinition.setAssetId(this.assetId);
        assetDefinition.setLang(lang);

        AssetDefinition.ManageContext manageContext1 = new AssetDefinition.ManageContext();
        manageContext1.setApplication(manageContext.getApplication());
        assetDefinition.setManageContext(manageContext1);


        return assetDefinition;
    }

    public Asset convertAsset() {
        Asset asset = new Asset();
        asset.setType(this.getType());
        asset.setCode(this.code);
        asset.setAssetName(this.assetName);
        asset.setBusinessData(this.businessData);
        asset.setManageContext(this.manageContext);
        asset.setShowFields(this.showFields);

        asset.setSource(AssetDefinition.SD_SOURCE);
        asset.setLang(this.lang);

        return asset;
    }
}

==> designer-asset-1.0.10-20251128.060327-19-sources.jar: com/digiwin/athena/dto/asset/DesignerCreateAssetReqDto.java <==
package com.digiwin.athena.dto.asset;

import com.digiwin.athena.dto.action.MultiLanguageDTO;
import com.digiwin.athena.mongodb.domain.application.Asset;
import com.digiwin.athena.mongodb.domain.application.AssetDefinition;
import lombok.Data;

import java.util.Map;

@Data
public class DesignerCreateAssetReqDto {

    private String assetId;
    // 资产类型
    private String type;

    private String code;


    private String businessData;

    private String assetName;

    private String assetDesc;

    private Map<String, MultiLanguageDTO> lang;

    private Asset.ManageContext manageContext = new Asset.ManageContext();
    private Asset.ShowField showFields = new Asset.ShowField();

    public AssetDefinition convertAssetDefinition() {
        AssetDefinition assetDefinition = new AssetDefinition();
        assetDefinition.setType(this.type);
        assetDefinition.setCode(this.code);
        assetDefinition.setSource(AssetDefinition.SD_SOURCE);
        assetDefinition.setBusinessData(this.businessData);
        assetDefinition.setAssetName(this.assetName);
        assetDefinition.setAssetId(this.assetId);
        assetDefinition.setLang(lang);

        Asset.ManageContext manageContext1 = new Asset.ManageContext();
        manageContext1.setApplication(manageContext.getApplication());
        assetDefinition.setManageContext(manageContext1);


        return assetDefinition;
    }

    public Asset convertAsset() {
        Asset asset = new Asset();
        asset.setType(this.getType());
        asset.setCode(this.code);
        asset.setAssetName(this.assetName);
        asset.setBusinessData(this.businessData);
        asset.setManageContext(this.manageContext);
        asset.setShowFields(this.showFields);

        asset.setSource(AssetDefinition.SD_SOURCE);
        asset.setLang(this.lang);

        return asset;
    }
}
